@@ -53,10 +53,10 @@ def _normed_header_dict(h11_headers):
     # commas.
     name_to_values = {}
     for name, value in h11_headers:
-        name_to_values.setdefault(bytes(name), []).append(value)
+        name_to_values.setdefault(name, []).append(value)
     name_to_normed_value = {}
     for name, values in name_to_values.items():
-        name_to_normed_value[name] = bytearray(b", ").join(values)
+        name_to_normed_value[name] = b", ".join(values)
     return name_to_normed_value
 
 
